Re-exports
pub use requirement::REQUIREMENTS;pub use trace::TRACES;pub use linkme;
Macros
- requirement
- Define a single requirement as a static item with automatic registration.
- requirements
- Define multiple requirements in a single block.
Structs
- Matrix
- Collected traceability data: all requirements and their linked tests.
- Requirement
- A traceable requirement defined in source code.
- Test
Trace - A link between a test function and a requirement.
Enums
- Format
- Output format for the traceability matrix.
- Requirement
Type - Classification of a requirement.
Statics
Attribute Macros
- traces
- Link a test function to one or more requirements.